diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.html b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.html
new file mode 100644
index 000000000..d2d9b577d
--- /dev/null
+++ b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.html
@@ -0,0 +1,12 @@
+
{{dialoge_title_content}}
+
+
+
+ {{dialoge_content}}
+
+
+
+
+
+
+
diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.scss b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.scss
new file mode 100644
index 000000000..e69de29bb
diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.spec.ts b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.spec.ts
new file mode 100644
index 000000000..56b4907d0
--- /dev/null
+++ b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.spec.ts
@@ -0,0 +1,25 @@
+import { async, ComponentFixture, TestBed } from '@angular/core/testing';
+
+import { PdStatusChangeDialogueComponent } from './pd-status-change-dialogue.component';
+
+describe('PdStatusChangeDialogueComponent', () => {
+ let component: PdStatusChangeDialogueComponent;
+ let fixture: ComponentFixture;
+
+ beforeEach(async(() => {
+ TestBed.configureTestingModule({
+ declarations: [ PdStatusChangeDialogueComponent ]
+ })
+ .compileComponents();
+ }));
+
+ beforeEach(() => {
+ fixture = TestBed.createComponent(PdStatusChangeDialogueComponent);
+ component = fixture.componentInstance;
+ fixture.detectChanges();
+ });
+
+ it('should create', () => {
+ expect(component).toBeTruthy();
+ });
+});
diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.ts b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.ts
new file mode 100644
index 000000000..57eed34f7
--- /dev/null
+++ b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component.ts
@@ -0,0 +1,46 @@
+import { Component, OnInit, ViewChild , Input, Inject} from '@angular/core';
+import { NotifierService } from "angular-notifier";
+import {MatDialog,MatDialogRef,MAT_DIALOG_DATA } from '@angular/material';
+import { PdTrigerService } from '../../../pd-service/pd-triger.service';
+
+@Component({
+ selector: 'app-pd-status-change-dialogue',
+ templateUrl: './pd-status-change-dialogue.component.html',
+ styleUrls: ['./pd-status-change-dialogue.component.scss']
+})
+export class PdStatusChangeDialogueComponent implements OnInit {
+
+ conformation: Boolean = false;
+ private notifier: NotifierService;
+ dialoge_title_content: string;
+ dialoge_content: string;
+
+ constructor(notifier: NotifierService , private pd: PdTrigerService,private dialogRef: MatDialogRef,@Inject(MAT_DIALOG_DATA) public data: any)
+ {
+ this.notifier = notifier;
+ this.dialoge_title_content = this.data.pd_status=='INPROGRESS' ? 'Start PD' : this.data.pd_status=='COMPLETED' ? 'Complete PD' : 'Change PD Status';
+ this.dialoge_content =this.data.pd_status=='INPROGRESS' ? 'Are you starting the Discussions ?' : this.data.pd_status=='COMPLETED' ? 'Please confirm you are completing the Discussions and forwarding for Quality Check ?' : 'Change PD Status';
+ }
+
+ ngOnInit() {
+ }
+ changePDStatus(): void {
+ let update_status = {
+ "pd_id":this.data.pdid,
+ };
+ this.pd.editPdMasterDetails(update_status, this.data.pd_status).subscribe(result => {
+ if (result.status == 200) {
+ this.dialogRef.close({update_status:true});
+ this.notifier.notify('success', this.data.pd_status=='INPROGRESS' ? 'PD Started Successfully' : this.data.pd_status=='COMPLETED' ? 'PD Completed Successfully ?' : 'PD Updated Successfully');
+ }
+ else {
+ this.dialogRef.close({update_status:false});
+ this.notifier.notify('warning', 'Something Wents Wrong Try Again.!');
+ }
+ }, error => {
+ this.dialogRef.close({update_status:false});
+ this.notifier.notify('warning', 'Something Wents Wrong Try Again.!');
+ });
+ }
+
+}
diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.html b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.html
index d64492d12..0c4ce1a5f 100755
--- a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.html
+++ b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.html
@@ -30,7 +30,7 @@
-
+
diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/manage-pd.module.ts b/ng6-seed/src/app/personal-discussion/manage-pd/manage-pd.module.ts
index 0d4c8b595..ca98cfdcc 100755
--- a/ng6-seed/src/app/personal-discussion/manage-pd/manage-pd.module.ts
+++ b/ng6-seed/src/app/personal-discussion/manage-pd/manage-pd.module.ts
@@ -108,6 +108,7 @@ import { ManageHouseHoldComponent } from './list-pd/start-pd/forms/assessed-inco
import { ManageOtherBusinessIncomeComponent } from './list-pd/start-pd/forms/assessed-income/AI-diologue/manage-other-business-income/manage-other-business-income.component';
import { GrossProfitCalculationComponent } from './list-pd/start-pd/forms/assessed-income/gross-profit-calculation/gross-profit-calculation.component';
import { ManageDailySalesComponent } from './list-pd/start-pd/forms/assessed-income/AI-diologue/manage-daily-sales/manage-daily-sales.component';
+import { PdStatusChangeDialogueComponent } from './list-pd/pd-status-change-dialogue/pd-status-change-dialogue.component';
/**
* Custom angular notifier options
*/
@@ -153,143 +154,8 @@ const pdCustomNotifierOptions: NotifierOptions = {
};
@NgModule({
-// <<<<<<< HEAD
-// imports: [
-// CommonModule,
-// ManagePdRoutingModule,
-// NotifierModule.withConfig(pdCustomNotifierOptions),
-// MatCardModule,
-// MatIconModule,
-// MatInputModule,
-// MatRadioModule,
-// MatTableModule,
-// MatPaginatorModule,
-// MatButtonModule,
-// MatProgressBarModule,
-// MatToolbarModule,
-// FlexLayoutModule,
-// NgxDatatableModule,
-// FormsModule,MatSlideToggleModule,
-// MatSelectModule, MatListModule,MatGridListModule, MatTabsModule, MatBadgeModule, MatCheckboxModule,MatStepperModule,MatSidenavModule ,MatMenuModule, MatButtonToggleModule,
-// ReactiveFormsModule,
-// FileUploadModule,
-// TreeModule,
-// MatDatepickerModule,
-// MatDialogModule,MatSortModule,
-// NgxMatSelectSearchModule,MatTooltipModule, MatExpansionModule,
-// AgmCoreModule.forRoot({apiKey: 'AIzaSyBtdO5k6CRntAMJCF-H5uZjTCoSGX95cdk'}),OwlDateTimeModule,
-// OwlNativeDateTimeModule,
-// ],
-// declarations: [RentalInfoComponent,
-// TelePdAllocationComponent,
-// FinancialInfoComponent,
-// BusinessInfoComponent,
-// EmploymentInfoComponent,
-// StockComponent,
-// BankingDetailsComponent,
-// ListPdComponent,
-// FamilyDetailsComponent,
-// AddressComponent,
-// ManagePdComponent,
-// MapPdViewComponent,
-// AddPdComponent,
-// ViewPdComponent,
-// PdAllocationComponent,
-// SmartPdAllocationComponent,
-// SchedulePdComponent,
-// EditPdApplicantComponent,
-// EditPdMasterComponent,
-// StartPdComponent,
-// InprogressPdComponent,
-// AllPdComponent,
-// ScheduledPdComponent,
-// CompletedPdComponent,
-// QcCompletedPdComponent,
-// ClientInfoComponent,
-// CurrentLoanComponent,
-// AssetsInfoComponent,
-// LoanDetailsComponent,
-// OtherIncomeComponent,
-// SupplierInfoComponent,
-// PersonalInfoComponent,
-// LenderRepresentativeComponent,
-// PdReportComponent,
-// AssessedIncomeComponent,
-// AllocationViewMoreComponent],
-
-// exports: [PdAllocationComponent,
-// SmartPdAllocationComponent,
-// TelePdAllocationComponent,
-// SchedulePdComponent,
-// EditPdApplicantComponent,
-// EditPdMasterComponent,
-// StartPdComponent,
-// CompletedPdComponent,
-// QcCompletedPdComponent,
-// AllocationViewMoreComponent],
-
-// providers: [PdTrigerService,
-// GetGeometricLocationService],
-
-// entryComponents: [PdAllocationComponent,
-// SmartPdAllocationComponent,
-// SchedulePdComponent,
-// EditPdApplicantComponent,
-// EditPdMasterComponent,
-// TelePdAllocationComponent,
-// AllocationViewMoreComponent,
-
-// PersonalInfoComponent,
-// ClientInfoComponent,
-// SupplierInfoComponent,
-// CurrentLoanComponent,
-// LoanDetailsComponent,
-// OtherIncomeComponent,
-// AssetsInfoComponent,
-// AddressComponent,
-// FamilyDetailsComponent,
-// BankingDetailsComponent,
-// StockComponent,
-// EmploymentInfoComponent,
-// BusinessInfoComponent,
-// FinancialInfoComponent,
-// LenderRepresentativeComponent,
-// RentalInfoComponent,
-// AssessedIncomeComponent],
-// =======
- // imports: [
- // CommonModule,
- // ManagePdRoutingModule,
- // NotifierModule.withConfig(pdCustomNotifierOptions),
- // MatCardModule,
- // MatIconModule,
- // MatInputModule,
- // MatRadioModule,
- // MatTableModule,
- // MatPaginatorModule,
- // MatButtonModule,
- // MatProgressBarModule,
- // MatAutocompleteModule,
- // MatToolbarModule,
- // FlexLayoutModule,
- // NgxDatatableModule,
- // FormsModule,
- // MatSlideToggleModule,
- // MatSelectModule, MatListModule, MatGridListModule, MatTabsModule, MatBadgeModule, MatCheckboxModule, MatStepperModule, MatSidenavModule, MatMenuModule, MatButtonToggleModule,
- // ReactiveFormsModule,
- // FileUploadModule,
- // TreeModule,
- // MatDialogModule, MatSortModule,
- // NgxMatSelectSearchModule, MatTooltipModule, MatExpansionModule,
- // AgmCoreModule.forRoot({apiKey: 'AIzaSyBtdO5k6CRntAMJCF-H5uZjTCoSGX95cdk'}), OwlDateTimeModule,
- // OwlNativeDateTimeModule,
- // ],
- declarations: [RentalInfoComponent, TelePdAllocationComponent, FinancialInfoComponent, BusinessInfoComponent, EmploymentInfoComponent, StockComponent, BankingDetailsComponent, ListPdComponent, FamilyDetailsComponent, AddressComponent, ManagePdComponent, MapPdViewComponent, AddPdComponent, ViewPdComponent, PdAllocationComponent, SmartPdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, StartPdComponent, InprogressPdComponent, AllPdComponent, ScheduledPdComponent, CompletedPdComponent, QcCompletedPdComponent, ClientInfoComponent, CurrentLoanComponent, AssetsInfoComponent, LoanDetailsComponent, OtherIncomeComponent, SupplierInfoComponent, PersonalInfoComponent, LenderRepresentativeComponent, PdReportComponent, AssessedIncomeComponent, AllocationViewMoreComponent, PdRequirementComponent, GeneralInfoComponent, ModelEditPdReportComponent, OtherApplicantDetailsComponent, NeighbourHoodComponent, DialogChangeCurrentVenrsion, FinalRemarksComponent, BusinessOtherFamilyMemberComponent, QcReviewComponent, BusinessInfoGroupComponent, SearchRelationPipe, DeleteRecordsCountPipe, BusinessAssetsInfoComponent, BusinessBankingDetailsComponent, SalesDetailsComponent, DailySalesDetailsComponent, SalesCalculationComponent, ManageSalesComponent, PurchaseDetailsComponent, BusinessExpenseDetailsComponent, HouseHoldDetailsComponent, OtherBusinessIncomeDetailsComponent, ManagePurchaseComponent, ManageBusinesExpenseComponent, ManageHouseHoldComponent, ManageOtherBusinessIncomeComponent, GrossProfitCalculationComponent, ManageDailySalesComponent],
-
- // exports: [PdAllocationComponent, SmartPdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, StartPdComponent, CompletedPdComponent, QcCompletedPdComponent],
- // providers: [PdTrigerService, GetGeometricLocationService],
- // entryComponents: [PdAllocationComponent, SmartPdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent],
- imports: [
+ declarations: [RentalInfoComponent, TelePdAllocationComponent, FinancialInfoComponent, BusinessInfoComponent, EmploymentInfoComponent, StockComponent, BankingDetailsComponent, ListPdComponent, FamilyDetailsComponent, AddressComponent, ManagePdComponent, MapPdViewComponent, AddPdComponent, ViewPdComponent, PdAllocationComponent, SmartPdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, StartPdComponent, InprogressPdComponent, AllPdComponent, ScheduledPdComponent, CompletedPdComponent, QcCompletedPdComponent, ClientInfoComponent, CurrentLoanComponent, AssetsInfoComponent, LoanDetailsComponent, OtherIncomeComponent, SupplierInfoComponent, PersonalInfoComponent, LenderRepresentativeComponent, PdReportComponent, AssessedIncomeComponent, AllocationViewMoreComponent, PdRequirementComponent, GeneralInfoComponent, ModelEditPdReportComponent, OtherApplicantDetailsComponent, NeighbourHoodComponent, DialogChangeCurrentVenrsion, FinalRemarksComponent, BusinessOtherFamilyMemberComponent, QcReviewComponent, BusinessInfoGroupComponent, SearchRelationPipe, DeleteRecordsCountPipe, BusinessAssetsInfoComponent, BusinessBankingDetailsComponent, SalesDetailsComponent, DailySalesDetailsComponent, SalesCalculationComponent, ManageSalesComponent, PurchaseDetailsComponent, BusinessExpenseDetailsComponent, HouseHoldDetailsComponent, OtherBusinessIncomeDetailsComponent, ManagePurchaseComponent, ManageBusinesExpenseComponent, ManageHouseHoldComponent, ManageOtherBusinessIncomeComponent, GrossProfitCalculationComponent, ManageDailySalesComponent, PdStatusChangeDialogueComponent],
+ imports: [
CommonModule,
ManagePdRoutingModule,
NgxViewerModule,
@@ -321,14 +187,13 @@ const pdCustomNotifierOptions: NotifierOptions = {
AgmCoreModule.forRoot({apiKey: 'AIzaSyBtdO5k6CRntAMJCF-H5uZjTCoSGX95cdk'}),OwlDateTimeModule,
OwlNativeDateTimeModule,
],
- // declarations: [ListPdComponent, ManagePdComponent, MapPdViewComponent, AddPdComponent, ViewPdComponent, PdAllocationComponent, SmartPdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, StartPdComponent, InprogressPdComponent, AllPdComponent, ScheduledPdComponent, CompletedPdComponent, QcCompletedPdComponent, ClientInfoComponent, SupplierInfoComponent, PersonalInfoComponent, AssetsInfoComponent],
- exports: [PdAllocationComponent, SmartPdAllocationComponent, TelePdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, StartPdComponent, CompletedPdComponent, QcCompletedPdComponent, ClientInfoComponent, SupplierInfoComponent, PersonalInfoComponent, CurrentLoanComponent, LoanDetailsComponent, OtherIncomeComponent, AssetsInfoComponent, AddressComponent, FamilyDetailsComponent, BankingDetailsComponent, StockComponent, EmploymentInfoComponent, BusinessInfoComponent, FinancialInfoComponent, LenderRepresentativeComponent,RentalInfoComponent, AssessedIncomeComponent, AllocationViewMoreComponent, GeneralInfoComponent, PdRequirementComponent, OtherApplicantDetailsComponent, NeighbourHoodComponent, BusinessOtherFamilyMemberComponent, BusinessInfoGroupComponent,DailySalesDetailsComponent, SalesCalculationComponent, PurchaseDetailsComponent, BusinessExpenseDetailsComponent, HouseHoldDetailsComponent, OtherBusinessIncomeDetailsComponent, ManageSalesComponent, ManagePurchaseComponent, ManageBusinesExpenseComponent, ManageHouseHoldComponent, ManageOtherBusinessIncomeComponent, GrossProfitCalculationComponent, ManageDailySalesComponent],
+ exports: [PdAllocationComponent, SmartPdAllocationComponent, TelePdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, StartPdComponent, CompletedPdComponent, QcCompletedPdComponent, ClientInfoComponent, SupplierInfoComponent, PersonalInfoComponent, CurrentLoanComponent, LoanDetailsComponent, OtherIncomeComponent, AssetsInfoComponent, AddressComponent, FamilyDetailsComponent, BankingDetailsComponent, StockComponent, EmploymentInfoComponent, BusinessInfoComponent, FinancialInfoComponent, LenderRepresentativeComponent,RentalInfoComponent, AssessedIncomeComponent, AllocationViewMoreComponent, GeneralInfoComponent, PdRequirementComponent, OtherApplicantDetailsComponent, NeighbourHoodComponent, BusinessOtherFamilyMemberComponent, BusinessInfoGroupComponent,DailySalesDetailsComponent, SalesCalculationComponent, PurchaseDetailsComponent, BusinessExpenseDetailsComponent, HouseHoldDetailsComponent, OtherBusinessIncomeDetailsComponent, ManageSalesComponent, ManagePurchaseComponent, ManageBusinesExpenseComponent, ManageHouseHoldComponent, ManageOtherBusinessIncomeComponent, GrossProfitCalculationComponent, ManageDailySalesComponent, PdStatusChangeDialogueComponent],
providers: [PdTrigerService, GetGeometricLocationService,{provide: MAT_DATE_LOCALE, useValue: 'en-GB'},
{provide: DateAdapter, useClass: MomentDateAdapter, deps: [MAT_DATE_LOCALE]},
{provide: MAT_DATE_FORMATS, useValue: MAT_MOMENT_DATE_FORMATS}],
entryComponents: [PdAllocationComponent, SmartPdAllocationComponent, SchedulePdComponent, EditPdApplicantComponent, EditPdMasterComponent, TelePdAllocationComponent, AllocationViewMoreComponent, PersonalInfoComponent,BusinessAssetsInfoComponent,
- ClientInfoComponent, SupplierInfoComponent, CurrentLoanComponent, LoanDetailsComponent, OtherIncomeComponent, AssetsInfoComponent, AddressComponent, FamilyDetailsComponent, BankingDetailsComponent, StockComponent, EmploymentInfoComponent, BusinessInfoComponent, FinancialInfoComponent, LenderRepresentativeComponent,RentalInfoComponent, AssessedIncomeComponent, GeneralInfoComponent, PdRequirementComponent, ModelEditPdReportComponent, OtherApplicantDetailsComponent, NeighbourHoodComponent, DialogChangeCurrentVenrsion, FinalRemarksComponent, BusinessOtherFamilyMemberComponent, QcReviewComponent, BusinessInfoGroupComponent,BusinessBankingDetailsComponent, ManageSalesComponent, ManagePurchaseComponent, ManageBusinesExpenseComponent, ManageHouseHoldComponent, ManageOtherBusinessIncomeComponent, ManageDailySalesComponent],
+ ClientInfoComponent, SupplierInfoComponent, CurrentLoanComponent, LoanDetailsComponent, OtherIncomeComponent, AssetsInfoComponent, AddressComponent, FamilyDetailsComponent, BankingDetailsComponent, StockComponent, EmploymentInfoComponent, BusinessInfoComponent, FinancialInfoComponent, LenderRepresentativeComponent,RentalInfoComponent, AssessedIncomeComponent, GeneralInfoComponent, PdRequirementComponent, ModelEditPdReportComponent, OtherApplicantDetailsComponent, NeighbourHoodComponent, DialogChangeCurrentVenrsion, FinalRemarksComponent, BusinessOtherFamilyMemberComponent, QcReviewComponent, BusinessInfoGroupComponent,BusinessBankingDetailsComponent, ManageSalesComponent, ManagePurchaseComponent, ManageBusinesExpenseComponent, ManageHouseHoldComponent, ManageOtherBusinessIncomeComponent, ManageDailySalesComponent,PdStatusChangeDialogueComponent],
})
export class ManagePdModule {
diff --git a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.ts b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.ts
index 0af985710..1ea24c5e5 100755
--- a/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.ts
+++ b/ng6-seed/src/app/personal-discussion/manage-pd/list-pd/start-pd/start-pd.component.ts
@@ -28,7 +28,7 @@ import {NeighbourHoodComponent} from './forms/neighbour-hood/neighbour-hood.comp
import {FinalRemarksComponent} from './forms/final-remarks/final-remarks.component';
import { BusinessInfoGroupComponent } from './forms/business-info-group/business-info-group.component';
import { BusinessAssetsInfoComponent } from './forms/business-assets-info/business-assets-info.component';
-
+import { PdStatusChangeDialogueComponent } from './../pd-status-change-dialogue/pd-status-change-dialogue.component';
@Component({
selector: 'app-start-pd',
templateUrl: './start-pd.component.html',
@@ -83,14 +83,9 @@ export class StartPdComponent implements OnInit, OnDestroy {
// Ps.initialize(elemSidebar, { wheelSpeed: 2, suppressScrollX: true });
// Ps.initialize(elemContent, { wheelSpeed: 2, suppressScrollX: true });
}
-
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,1);
}
- // start
-
-
- // end
-
+
isMac(): boolean {
let bool = false;
if (navigator.platform.toUpperCase().indexOf('MAC') >= 0 || navigator.platform.toUpperCase().indexOf('IPAD') >= 0) {
@@ -103,7 +98,9 @@ export class StartPdComponent implements OnInit, OnDestroy {
return window.matchMedia(`(max-width: 960px)`).matches;
}
- loadTemplates(startID:string){
+
+ // load templates details
+ loadTemplates(startID:string,type:number){
this._pd.loadPDTemplates(startID).subscribe(
data => {
if (data.status == 200) {
@@ -117,9 +114,10 @@ export class StartPdComponent implements OnInit, OnDestroy {
this.actualQuestions = this.categoryFormButtons.length;
let getAnsweredFormsCount = this.categoryFormButtons.filter(item=>item.isAnswered===true);
this.answeredQuestions = getAnsweredFormsCount.length;
- this.pdFullDetails = data.records
-
-
+ this.pdFullDetails = data.records;
+ if(type==1 && data.records.pdmaster_details.pd_status=='SCHEDULED') {
+ this.pdStatusDialogue(this.pdStatusCheck.INPROGRESS)
+ }
}
else{
this.pdMasterList = "";
@@ -132,26 +130,22 @@ export class StartPdComponent implements OnInit, OnDestroy {
});
}
-
-
- //change pd status
- changePDStatus(status: string) {
-
- let update_array = {
- "pd_id": this.startPD
- }
- this._pd.editPdMasterDetails(update_array, status).subscribe(result => {
- if (result.status == 200) {
- this.currentPDStatus = false;
- this.notifier.notify('success', 'PD Completed.');
- }
- else {
- this.notifier.notify('warning', 'Something Wents Wrong Try Again.!');
- }
- }, error => {
- this.notifier.notify('warning', 'Something Wents Wrong Try Again.!');
+ // load pd status change dialogue
+ pdStatusDialogue(status: string): void {
+ const dialogRef = this.dialog.open(PdStatusChangeDialogueComponent, {
+ data: { pdid: this.startPD, pd_status: status },
+ disableClose: true,
+ minWidth:'20%',
+ maxWidth:'40%',
+ });
+ dialogRef.afterClosed()
+ .subscribe(dataresult => {
+ if(dataresult.update_status==true){
+ this.loadTemplates(this.startPD,2);
+ }
});
- }
+}
+
// start
// direct form based questions
OnSelectDirectForms(details: any) {
@@ -168,7 +162,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==2){
@@ -181,7 +175,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==3){
@@ -194,7 +188,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==4){
@@ -207,7 +201,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==5){
@@ -220,7 +214,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==6){
@@ -233,7 +227,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==7){
@@ -246,7 +240,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}
else
@@ -260,7 +254,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}
else
@@ -274,7 +268,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==10){
@@ -287,7 +281,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==11){
@@ -300,7 +294,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==12){
@@ -313,7 +307,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==13){
@@ -326,7 +320,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==14){
@@ -339,7 +333,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==15){
@@ -352,7 +346,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}
else
@@ -366,7 +360,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==17){
@@ -379,7 +373,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}
else if(this.selectedFormsCategory.form_id==18){
@@ -392,7 +386,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
generaldialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}
else if(this.selectedFormsCategory.form_id==19){
@@ -405,7 +399,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
generaldialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else if(this.selectedFormsCategory.form_id==20){
const generaldialogRef = this.dialog.open(FinalRemarksComponent, {
@@ -417,7 +411,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
generaldialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}else
if(this.selectedFormsCategory.form_id==22){
@@ -430,7 +424,7 @@ export class StartPdComponent implements OnInit, OnDestroy {
dialogRef.afterClosed()
.subscribe(dataresult => {
// this.notifier.notify('success', 'Successfully allocated.!');
- this.loadTemplates(this.startPD);
+ this.loadTemplates(this.startPD,2);
});
}